import { Component, OnInit, ViewChild } from '@angular/core';
import { Ingredient } from '../models/ingredient';
import { IngredientService } from '../services/ingredient.service';
import { MatTableModule, MatTableDataSource } from '@angular/material/table';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-ingredient-list',
  standalone: true,
  templateUrl: './ingredient-list.component.html',
  styleUrls: ['./ingredient-list.component.scss'],
  imports: [CommonModule, MatTableModule, MatPaginatorModule],
})
export class IngredientListComponent implements OnInit {
  ingredients: Ingredient[] = [];
  dataSource: MatTableDataSource<Ingredient> =
    new MatTableDataSource<Ingredient>();
  displayedColumns: string[] = ['id', 'name'];

  @ViewChild(MatPaginator) paginator!: MatPaginator;

  constructor(private ingredientService: IngredientService) {}

  ngOnInit(): void {
    this.ingredients = this.ingredientService.getIngredients();
    this.dataSource.data = this.ingredients;
  }

  ngAfterViewInit() {
    this.dataSource.paginator = this.paginator;
  }
}
